==> clabe-1.2.6-py3-none-any.whl: clabe/banks.py <==
BANKS = {
    '706': '90706',
    '138': '40138',
    '102': '40102',
    '614': '90614',
    '133': '40133',
    '062': '40062',
    '638': '90638',
    '103': '40103',
    '652': '90652',
    '659': '90659',
    '128': '40128',
    '674': '90674',
    '127': '40127',
    '030': '40030',
    '002': '40002',
    '154': '40154',
    '006': '37006',
    '137': '40137',
    '160': '40160',
    '152': '40152',
    '019': '37019',
    '147': '40147',
    '106': '40106',
    '009': '37009',
    '072': '40072',
    '058': '40058',
    '166': '37166',
    '060': '40060',
    '001': '2001',
    '129': '40129',
    '145': '40145',
    '012': '40012',
    '112': '40112',
    '677': '90677',
    '683': '90683',
    '630': '90630',
    '143': '40143',
    '631': '90631',
    '901': '90901',
    '130': '40130',
    '140': '40140',
    '126': '40126',
    '680': '90680',
    '124': '40124',
    '151': '40151',
    '606': '90606',
    '648': '90648',
    '616': '90616',
    '634': '90634',
    '679': '90679',
    '689': '90689',
    '685': '90685',
    '601': '90601',
    '636': '90636',
    '168': '37168',
    '021': '40021',
    '155': '40155',
    '036': '40036',
    '902': '90902',
    '150': '40150',
    '136': '40136',
    '686': '90686',
    '059': '40059',
    '110': '40110',
    '670': '90670',
    '602': '90602',
    '042': '40042',
    '158': '40158',
    '600': '90600',
    '108': '40108',
    '132': '40132',
    '613': '90613',
    '135': '37135',
    '637': '90637',
    '649': '90649',
    '148': '40148',
    '620': '90620',
    '642': '90642',
    '156': '40156',
    '014': '40014',
    '044': '40044',
    '623': '90623',
    '655': '90655',
    '646': '90646',
    '684': '90684',
    '656': '90656',
    '617': '90617',
    '605': '90605',
    '608': '90608',
    '113': '40113',
    '141': '40141',
    '903': '90903',
}


# Descargado de http://www.banxico.org.mx/cep/ por 2019-01-21
BANK_NAMES = {
    '40138': 'ABC Capital',
    '40102': 'Accendo Banco',
    '90614': 'Accival',
    '40133': 'Actinver',
    '40062': 'Afirme',
    '90638': 'Akala',
    '90706': 'Arcus',
    '40103': 'American Express',
    '90652': 'Asea',
    '90659': 'Asp Integra Opc',
    '40128': 'Autofin',
    '90674': 'Axa',
    '40127': 'Azteca',
    '40030': 'Bajio',
    '40002': 'Banamex',
    '40154': 'Banco Finterra',
    '37006': 'Bancomext',
    '40137': 'Bancoppel',
    '40160': 'Banco S3',
    '40152': 'Bancrea',
    '37019': 'Banjercito',
    '40147': 'Bankaool',
    '40106': 'Bank Of America',
    '37009': 'Banobras',
    '40072': 'Banorte/Ixe',
    '40058': 'Banregio',
    '37166': 'Bansefi',
    '40060': 'Bansi',
    '2001': 'Banxico',
    '40129': 'Barclays',
    '40145': 'Banco BASE',
    '40012': 'BBVA Bancomer',
    '40112': 'Bmonex',
    '90677': 'Caja Pop Mexica',
    '90683': 'Caja Telefonist',
    '90630': 'CB Intercam',
    '40143': 'CIbanco',
    '90631': 'CI Bolsa',
    '90901': 'Cls',
    '90903': 'CoDi Valida',
    '40130': 'Compartamos',
    '40140': 'Consubanco',
    '40126': 'Credit Suisse',
    '90680': 'Cristobal Colon',
    '40124': 'Deutsche',
    '40151': 'Donde',
    '90606': 'Estructuradores',
    '90648': 'Evercore',
    '90616': 'Finamex',
    '90634': 'Fincomun',
    '90679': 'Fnd',
    '90689': 'Fomped',
    '90685': 'Fondo (Fira)',
    '90601': 'Gbm',
    '90636': 'Hdi Seguros',
    '37168': 'Hipotecaria Fed',
    '40021': 'HSBC',
    '40155': 'Icbc',
    '40036': 'Inbursa',
    '90902': 'Indeval',
    '40150': 'Inmobiliario',
    '40136': 'Intercam Banco',
    '90686': 'Invercap',
    '40059': 'Invex',
    '40110': 'JP Morgan',
    '90670': 'Libertad',
    '90602': 'Masari',
    '40042': 'Mifel',
    '40158': 'Mizuho Bank',
    '90600': 'Monexcb',
    '40108': 'Mufg',
    '40132': 'Multiva Banco',
    '90613': 'Multiva Cbolsa',
    '37135': 'Nafin',
    '90637': 'Order',
    '90649': 'Oskndia',
    '40148': 'Pagatodo',
    '90620': 'Profuturo',
    '90642': 'Reforma',
    '40156': 'Sabadell',
    '40014': 'Santander',
    '40044': 'Scotiabank',
    '90623': 'Skandia',
    '90655': 'Sofiexpress',
    '90646': 'STP',
    '90684': 'Transfer',
    '90656': 'Unagra',
    '90617': 'Valmex',
    '90605': 'Value',
    '90608': 'Vector',
    '40113': 'Ve Por Mas',
    '40141': 'Volkswagen',
}

==> clabe-1.2.9-py3-none-any.whl: clabe/banks.py <==
BANKS = {
    '138': '40138',
    '133': '40133',
    '062': '40062',
    '661': '90661',
    '638': '90638',
    '706': '90706',
    '659': '90659',
    '128': '40128',
    '127': '40127',
    '166': '37166',
    '030': '40030',
    '002': '40002',
    '154': '40154',
    '006': '37006',
    '137': '40137',
    '160': '40160',
    '152': '40152',
    '019': '37019',
    '147': '40147',
    '106': '40106',
    '159': '40159',
    '009': '37009',
    '072': '40072',
    '058': '40058',
    '060': '40060',
    '001': '2001',
    '129': '40129',
    '145': '40145',
    '012': '40012',
    '112': '40112',
    '677': '90677',
    '683': '90683',
    '630': '90630',
    '143': '40143',
    '631': '90631',
    '901': '90901',
    '903': '90903',
    '130': '40130',
    '140': '40140',
    '652': '90652',
    '688': '90688',
    '126': '40126',
    '680': '90680',
    '151': '40151',
    '616': '90616',
    '634': '90634',
    '689': '90689',
    '685': '90685',
    '601': '90601',
    '168': '37168',
    '021': '40021',
    '155': '40155',
    '036': '40036',
    '902': '90902',
    '150': '40150',
    '136': '40136',
    '686': '90686',
    '059': '40059',
    '110': '40110',
    '653': '90653',
    '670': '90670',
    '602': '90602',
    '042': '40042',
    '158': '40158',
    '600': '90600',
    '108': '40108',
    '132': '40132',
    '613': '90613',
    '135': '37135',
    '710': '90710',
    '684': '90684',
    '148': '40148',
    '620': '90620',
    '156': '40156',
    '014': '40014',
    '044': '40044',
    '157': '40157',
    '646': '90646',
    '648': '90648',
    '656': '90656',
    '617': '90617',
    '605': '90605',
    '608': '90608',
    '113': '40113',
    '141': '40141',
}


# Descargado de https://www.banxico.org.mx/cep-scl/listaInstituciones.do
# 2022-10-18
BANK_NAMES = {
    '40138': 'ABC Capital',
    '40133': 'Actinver',
    '40062': 'Afirme',
    '90661': 'ALTERNATIVOS',
    '90706': 'Arcus',
    '90659': 'Asp Integra Opc',
    '40128': 'Autofin',
    '40127': 'Azteca',
    '37166': 'Babien',
    '40030': 'Bajio',
    '40002': 'Banamex',
    '40154': 'Banco Covalto',
    '37006': 'Bancomext',
    '40137': 'Bancoppel',
    '40160': 'Banco S3',
    '40152': 'Bancrea',
    '37019': 'Banjercito',
    '40147': 'Bankaool',
    '40106': 'Bank Of America',
    '40159': 'Bank Of China',
    '37009': 'Banobras',
    '40072': 'Banorte',
    '40058': 'Banregio',
    '40060': 'Bansi',
    '2001': 'Banxico',
    '40129': 'Barclays',
    '40145': 'BBase',
    '40012': 'BBVA Mexico',
    '40112': 'Bmonex',
    '90677': 'Caja Pop Mexica',
    '90683': 'Caja Telefonist',
    '90630': 'CB Intercam',
    '40143': 'CI Banco',
    '90631': 'CI Bolsa',
    '90901': 'Cls',
    '90903': 'CoDi Valida',
    '40130': 'Compartamos',
    '40140': 'Consubanco',
    '90652': 'Credicapital',
    '90688': 'Crediclub',
    '40126': 'Credit Suisse',
    '90680': 'Cristobal Colon',
    '40151': 'Donde',
    '90616': 'Finamex',
    '90634': 'Fincomun',
    '90689': 'Fomped',
    '90685': 'Fondo (Fira)',
    '90601': 'Gbm',
    '37168': 'Hipotecaria Fed',
    '40021': 'HSBC',
    '40155': 'Icbc',
    '40036': 'Inbursa',
    '90902': 'Indeval',
    '40150': 'Inmobiliario',
    '40136': 'Intercam Banco',
    '90686': 'Invercap',
    '40059': 'Invex',
    '40110': 'JP Morgan',
    '90653': 'Kuspit',
    '90670': 'Libertad',
    '90602': 'Masari',
    '40042': 'Mifel',
    '40158': 'Mizuho Bank',
    '90600': 'Monexcb',
    '40108': 'Mufg',
    '40132': 'Multiva Banco',
    '90613': 'Multiva Cbolsa',
    '37135': 'Nafin',
    '90638': 'NU MEXICO',
    '90710': 'NVIO',
    '90684': 'Opm',
    '40148': 'Pagatodo',
    '90620': 'Profuturo',
    '40156': 'Sabadell',
    '40014': 'Santander',
    '40044': 'Scotiabank',
    '40157': 'Shinhan',
    '90646': 'STP',
    '90648': 'Tactiv Cb',
    '90656': 'Unagra',
    '90617': 'Valmex',
    '90605': 'Value',
    '90608': 'Vector',
    '40113': 'Ve Por Mas',
    '40141': 'Volkswagen',
}
